==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Всі шрифти</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системні</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Вибрані</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активний</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>китайська</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Моноширинний</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде вилучено</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Вилучення</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде увімкено</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде вимкнено</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Вимкнути</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished">Застосувати до усіх позначених гарнітур шрифтів</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Скасувати</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Пошкоджений файл</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Уже встановлено ту саму версію</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Загальносистемний шрифт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Шрифти</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Встановлено %1 шрифт</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Встановлено %1 шрифтів</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Пошкоджений файл</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Цим шрифтом не можна буде скористатися у інших програмах</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ці шрифти будуть недоступними для програм</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>%1 інших загальносистемних шрифтів не може бути вилучено</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Шрифт «%1» використовується — його не можна вилучати</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Інші %1 загальносистемні шрифти і шрифт «%2», який використано у інших програмах, не може бути вилучено</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Ви справді хочете вилучити %1 шрифти?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Вилучення</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Вилучаємо шрифти. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Перевірка шрифту</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Не буде встановлено жодного шрифту</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Продовжити</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Нехай ваші мрії не лишаються лише мріями</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Базові відомості</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невідомий</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Назва повністю</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Назва PS</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Торговельна марка</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Керування шрифтами</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Засіб керування шрифтами допомагає користувачам встановлювати і вилучати шрифти.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Завантажуємо список шрифтів. Будь ласка, зачекайте…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Шрифт експортовано на вашу стільницю</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 шрифтів експортовано на вашу стільницю</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Не вдалося експортувати один шрифт. На диску недостатньо місця.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Не вдалося експортувати %1 шрифтів. На диску недостатньо місця.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Додати шрифт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучення</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити із вибраних</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у менеджері файлів</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>вимкнено</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Шрифти було деактивовано</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 використано якоюсь програмою — ви не можете його вимкнути</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Не можна вимикати загальносистемні шрифти або шрифти, які використовуються</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Не можна вимикати загальносистемні шрифти</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Встановити шрифт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Перевіряємо…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Невідомий</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Пошкоджений файл</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Встановлено</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Не встановлено</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Встановити шрифт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Немає шрифтів</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати клавіатурні скорочення</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>На сторінку вище</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>На сторінку нижче</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучення</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Додати шрифт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити із вибраних</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Дані щодо шрифту</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Введіть текст для попереднього перегляду</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Всі шрифти</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системні</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Вибрані</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активний</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>китайська</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Моноширинний</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде вилучено</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Вилучення</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде увімкено</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 є гарнітурою — якщо ви підтвердите виконання дії, усі шрифти у гарнітурі буде вимкнено</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Вимкнути</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Застосувати до усіх позначених гарнітур шрифтів</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Пошкоджений файл</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Уже встановлено ту саму версію</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Загальносистемний шрифт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Встановлено %1 шрифт</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Встановлено %1 шрифтів</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Не вдалося встановити %1 шрифтів. На диску недостатньо місця.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Цим шрифтом не можна буде скористатися у інших програмах</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ці шрифти будуть недоступними для програм</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>%1 інших загальносистемних шрифтів не може бути вилучено</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Шрифт «%1» використовується — його не можна вилучати</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Інші %1 загальносистемні шрифти і шрифт «%2», який використано у інших програмах, не може бути вилучено</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Ви справді хочете вилучити %1 шрифти?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Вилучення</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Вилучаємо шрифти. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Перевірка шрифту</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Не буде встановлено жодного шрифту</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Продовжити</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Базові відомості</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невідомий</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Назва повністю</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Назва PS</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Торговельна марка</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Керування шрифтами</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Засіб керування шрифтами допомагає користувачам встановлювати і вилучати шрифти.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Завантажуємо список шрифтів. Будь ласка, зачекайте…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Шрифт експортовано на вашу стільницю</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 шрифтів експортовано на вашу стільницю</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Не вдалося експортувати один шрифт. На диску недостатньо місця.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Не вдалося експортувати %1 шрифтів. На диску недостатньо місця.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Додати шрифт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучення</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити із вибраних</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у менеджері файлів</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>вимкнено</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Шрифти було деактивовано</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 використано якоюсь програмою — ви не можете його вимкнути</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Не можна вимикати загальносистемні шрифти або шрифти, які використовуються</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Не можна вимикати загальносистемні шрифти</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Встановити шрифт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Перевіряємо…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Невідомий</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Пошкоджений файл</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Встановлено</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Не встановлено</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Встановити шрифт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Немає шрифтів</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати клавіатурні скорочення</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>На сторінку вище</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>На сторінку нижче</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучення</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Додати шрифт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити із вибраних</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Дані щодо шрифту</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Введіть текст для попереднього перегляду</translation>
    </message>
</context>
</TS>
